<?php 
/**
 * Service
 * Goal section
 *
 * This is the template for the content of service_goal section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_service_goal_section' ) ) :
    /**
    * Add service_goal section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_service_goal_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if main_service is enabled
        $enable_goal_section = $options['goal_section_enable'];

        if ( true !== $enable_goal_section ) {
            return false;
        }

        // Get service_goal section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_service_goal_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render service_goal section now.
        corporate_education_pro_render_service_goal_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_service_goal_content', 'corporate_education_pro_add_service_goal_section', 10 );


if ( ! function_exists( 'corporate_education_pro_get_service_goal_section_details' ) ) :
    /**
    * service_goal section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input service_goal section details.
    */
    function corporate_education_pro_get_service_goal_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // service_goal type
        $service_goal_intro_content_type  = $options['goal_intro_content_type'];
        $service_goal_content_type  = $options['goal_content_type'];

        $content = array();

        switch ( $service_goal_intro_content_type ) {
            case 'custom':
                $content['intro'][1]['title']    = ! empty( $options['goal_intro_content_title'] ) ? $options['goal_intro_content_title'] : '';
                $content['intro'][1]['url']      = '';
                $content['intro'][1]['excerpt']  = ! empty( $options['goal_intro_content_description'] ) ? $options['goal_intro_content_description'] : '';
            break;        

            case 'post':
                $post_id = '';
                
                if ( ! empty( $options['goal_intro_content_post'] ) )
                    $post_id = absint( $options['goal_intro_content_post'] );

                // Bail if no valid pages are selected.
                if ( empty( $post_id ) ) {
                    return $input;
                }

                $content['intro'][1]['title']    = get_the_title( $post_id );
                $content['intro'][1]['url']      = get_the_permalink( $post_id );
                $content['intro'][1]['excerpt']  = corporate_education_pro_trim_content( 30 , get_post( $post_id ) );
                                            
            break;

            case 'page':
                $page_id = '';
                
                if ( ! empty( $options['goal_intro_content_page'] ) )
                    $page_id = absint( $options['goal_intro_content_page'] );

                // Bail if no valid pages are selected.
                if ( empty( $page_id ) ) {
                    return $input;
                }

                $content['intro'][1]['title']    = get_the_title( $page_id );
                $content['intro'][1]['url']      = get_the_permalink( $page_id );
                $content['intro'][1]['excerpt']  = corporate_education_pro_trim_content( 30, get_post( $page_id ) );
                                            
            break;
        }

        switch ( $service_goal_content_type ) {

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['goal_content_post'] ) )
                    $ids = ( array ) $options['goal_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 3,
                );  
                
          	break;

            case 'page':
                $ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    $id = null;
                    if ( isset( $options[ 'goal_content_page_'.$i ] ) ) {
                        $id = $options[ 'goal_content_page_'.$i ];
                    }
                    if ( ! empty( $id ) ) {
                        $ids[] = absint( $id );
                    }
                }

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'page',
                    'post__in'       => $ids,
                );
            break;


        }

        $posts = get_posts( $args );
        if ( ! empty( $posts ) ) :
            $i = 1;
            foreach ( $posts as $post ) :
                $post_id = $post->ID;
                $content['content'][$i]['id']       = $post_id;
                $content['content'][$i]['title']    = get_the_title( $post_id );
                $content['content'][$i]['url']      = get_the_permalink( $post_id );
                $content['content'][$i]['icon']     = get_post_meta( $post_id, 'corporate-education-pro-post-icon', true );
                $i++;
            endforeach;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service_goal section content details.
add_filter( 'corporate_education_pro_filter_service_goal_section_details', 'corporate_education_pro_get_service_goal_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_service_goal_section' ) ) :
    /**
    * Start service_goal section
    *
    * @return string service_goal content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_service_goal_section( $content_details ) {
        $options = corporate_education_pro_get_theme_options();
        $goal_intro_sub_title = ! empty( $options['goal_intro_content_sub_title'] ) ? $options['goal_intro_content_sub_title'] : '';
        $readmore   = ! empty( $options['read_more_text'] ) ? $options['read_more_text'] : esc_html__( 'Read More', 'corporate-education-pro' );
        
        if ( empty( $content_details ) ) {
            return;
        }
        ?>
        <section id="featured-goals" class="page-section col-2">
            <div class="gray-shape top move-up left"></div>
            <div class="white-shape top move-down right"></div>
            <div class="white-shape bottom move-down right"></div>
            <div class="wrapper">
                <div class="hentry">
                    <div class="entry-container">
                        <?php foreach( $content_details['intro'] as $content_detail ) : ?>
                            <header class="entry-header">
                                <h2 class="entry-title"><?php echo esc_html( $content_detail['title'] ); ?></h2>
                                <?php if ( ! empty( $goal_intro_sub_title ) ) : ?>
                                    <p class="entry-title-desc"><?php echo esc_html( $goal_intro_sub_title ); ?></p>
                                <?php endif; ?>
                            </header>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content_detail['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->
                            <?php if ( ! empty( $content_detail['url'] ) ) : ?>
                                <div class="view-more">
                                    <a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="btn btn-blue-transparent"><?php echo esc_html( $readmore ); ?></a>
                                </div><!-- .view-more -->
                            <?php endif; ?>
                        <?php endforeach; ?>
                    </div><!-- .entry-container -->
                </div><!-- .hentry -->

                <div class="hentry">
                    <div class="goal-lists col-3 clear">
                        <?php foreach ( $content_details['content'] as $content_detail ) : ?>
                            <div class="box">
                                <div class="white-shape top"></div>
                                <div class="white-shape top right"></div>
                                <div class="white-shape bottom"></div>
                                <div class="white-shape bottom left"></div>

                                <h5 class="featured-title">
                                    <a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a>
                                </h5>
                                <i class="fa <?php echo esc_attr( $content_detail['icon'] ); ?>"></i>
                            </div><!-- .box -->
                        <?php endforeach; ?>
                    </div><!-- .goal-lists -->
                </div><!-- .hentry -->
            </div><!-- .wrapper -->
        </section><!-- .featured-goals -->
       
    <?php }
endif;


/**
 * Service
 * main service section
 *
 * This is the template for the content of main_service section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_main_service_section' ) ) :
    /**
    * Add main_service section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_main_service_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if main_service is enabled
        $enable_main_service = $options['main_service_enable'];

        if ( true !== $enable_main_service ) {
            return false;
        }

        // Get main_service section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_main_service_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render main_service section now.
        corporate_education_pro_render_main_service_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_main_service_content', 'corporate_education_pro_add_main_service_section', 10 );


if ( ! function_exists( 'corporate_education_pro_get_main_service_section_details' ) ) :
    /**
    * main_service section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input main_service section details.
    */
    function corporate_education_pro_get_main_service_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // main_service type
        $main_service_content_type  = $options['main_service_content_type'];

        $content = array();
        switch ( $main_service_content_type ) {

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['main_service_content_post'] ) )
                    $ids = ( array ) $options['main_service_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 4,
                );  
                
            break;

            case 'page':
                $ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    $id = null;
                    if ( isset( $options[ 'main_service_content_page_'.$i ] ) ) {
                        $id = $options[ 'main_service_content_page_'.$i ];
                    }
                    if ( ! empty( $id ) ) {
                        $ids[] = absint( $id );
                    }
                }

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'page',
                    'post__in'       => $ids,
                );
            break;


        }

        $posts = get_posts( $args );
        if ( ! empty( $posts ) ) :
            $i = 1;
            foreach ( $posts as $post ) :
                $post_id = $post->ID;
                $content[$i]['id']       = $post_id;
                $content[$i]['title']    = get_the_title( $post_id );
                $content[$i]['url']      = get_the_permalink( $post_id );
                $content[$i]['excerpt']  = corporate_education_pro_trim_content( 20, $post );
                $i++;
            endforeach;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// main_service section content details.
add_filter( 'corporate_education_pro_filter_main_service_section_details', 'corporate_education_pro_get_main_service_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_main_service_section' ) ) :
    /**
    * Start main_service section
    *
    * @return string main_service content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_main_service_section( $content_details ) {
        $options = corporate_education_pro_get_theme_options();
        $title = $options['main_service_title'] ? $options['main_service_title'] : '';
        $sub_title = $options['main_service_sub_title'] ? $options['main_service_sub_title'] : '';
        $image  = $options['main_service_image'] ? $options['main_service_image'] :  get_template_directory_uri() . '/assets/uploads/main-service.jpg';
        
        if ( empty( $content_details ) ) {
            return;
        }

        $i = 1;
        ?>

        <section id="main-services" class="page-section no-padding-bottom">
            <div class="blue-shape top move-up left"></div>
            <div class="white-shape bottom left"></div>
            <div class="blue-shape bottom move-down right"></div>

            <div class="wrapper">
                <?php if ( ! empty( $title ) || ! empty( $sub_title ) ) : ?>
                    <header class="entry-header">
                        <h2 class="entry-title"><?php echo esc_html( $title ); ?></h2>
                        <p class="entry-title-desc"><?php echo esc_html( $sub_title ); ?></p>
                    </header>
                <?php endif; ?>

                <div class="entry-content col-3">
                    <div class="hentry">
                        <?php foreach ( $content_details as $content_detail ) : ?>
                            <div class="service">
                                <h5 class="featured-title"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                                <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                            </div><!-- .service -->
                            <?php if ( $i == 2 ) : ?>
                                </div><!-- .hentry -->

                                <div class="hentry">
                                    <div class="image-cover">
                                        <div class="featured-image" style="background-image:url('<?php echo esc_url( $image ); ?>')">
                                        </div><!-- .featured-image -->
                                    </div><!-- .image-cover -->
                                </div><!-- .hentry -->

                                <div class="hentry">
                            <?php endif;
                            $i++; 
                        endforeach; ?>
                        
                    </div><!-- .hentry -->
                </div><!-- .entry-content -->
            </div><!-- .wrapper -->
        </section><!-- #main-services -->
       
    <?php }
endif;


/**
 * Service
 * quality service section
 *
 * This is the template for the content of quality_service section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_quality_service_section' ) ) :
    /**
    * Add quality_service section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_quality_service_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if quality_service is enabled
        $enable_quality_service = $options['quality_service_enable'];

        if ( true !== $enable_quality_service ) {
            return false;
        }

        // Get quality_service section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_quality_service_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render quality_service section now.
        corporate_education_pro_render_quality_service_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_quality_service_content', 'corporate_education_pro_add_quality_service_section', 10 );


if ( ! function_exists( 'corporate_education_pro_get_quality_service_section_details' ) ) :
    /**
    * quality_service section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input quality_service section details.
    */
    function corporate_education_pro_get_quality_service_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // quality_service type
        $quality_service_content_type  = $options['quality_service_content_type'];

        $content = array();
        switch ( $quality_service_content_type ) {

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['quality_service_content_post'] ) )
                    $ids = ( array ) $options['quality_service_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 9,
                );  
                
            break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['quality_service_content_category'] ) ) {
                    $cat_id = $options['quality_service_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => absint( $options['quality_service_count'] ),
                );
            break;


        }

        $posts = get_posts( $args );
        if ( ! empty( $posts ) ) :
            $i = 1;
            foreach ( $posts as $post ) :
                $post_id = $post->ID;
                $content[$i]['icon']     = get_post_meta( $post_id, 'corporate-education-pro-post-icon', true );
                $content[$i]['title']    = get_the_title( $post_id );
                $content[$i]['url']      = get_the_permalink( $post_id );
                $content[$i]['excerpt']  = corporate_education_pro_trim_content( 15, $post );
                $i++;
            endforeach;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// quality_service section content details.
add_filter( 'corporate_education_pro_filter_quality_service_section_details', 'corporate_education_pro_get_quality_service_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_quality_service_section' ) ) :
    /**
    * Start quality_service section
    *
    * @return string quality_service content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_quality_service_section( $content_details ) {
        $options = corporate_education_pro_get_theme_options();
        $title = $options['quality_service_title'] ? $options['quality_service_title'] : '';
        $sub_title = $options['quality_service_sub_title'] ? $options['quality_service_sub_title'] : '';
        
        if ( empty( $content_details ) ) {
            return;
        }
        ?>

        <section id="reasons" class="page-section">
            <div class="white-shape bottom right move-down"></div>
            <div class="wrapper">
                <?php if ( ! empty( $title ) || ! empty( $sub_title ) ) : ?>
                    <header class="entry-header align-center">
                        <?php if ( ! empty( $title ) ) : ?>
                            <h2 class="entry-title"><?php echo esc_html( $title ); ?></h2>
                        <?php endif; 
                        if ( ! empty( $sub_title ) ) : ?>
                            <p class="entry-title-desc"><?php echo esc_html( $sub_title ); ?></p>
                        <?php endif; ?>
                    </header>
                <?php endif; ?>

                <div class="entry-content col-3">
                    <?php foreach ( $content_details as $content_detail ) : ?>
                        <div class="hentry">
                            <div class="icon">
                                <a href="<?php echo esc_url( $content_detail['url'] ); ?>">
                                    <i class="fa <?php echo esc_attr( $content_detail['icon'] ); ?>"></i>
                                </a>
                            </div><!-- .icon -->
                            <div class="details">
                                <h5 class="featured-title">
                                    <a href="<?php echo esc_url( $content_detail['url'] ); ?>">
                                        <?php echo esc_html( $content_detail['title'] ); ?>
                                    </a>
                                </h5>
                                <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                            </div><!-- .details -->
                        </div><!-- .hentry -->
                    <?php endforeach; ?>
                </div><!-- .entry-content -->
            </div><!-- .wrapper -->
        </section><!-- #reasons -->
       
    <?php }
endif;
