<?php 
/**
 * Call to action  section
 *
 * This is the template for the content of call_to_action section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_call_to_action_section' ) ) :
    /**
    * Add call_to_action section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_call_to_action_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if call_to_action is enabled
        $enable_call_to_action = apply_filters( 'corporate_education_pro_section_status', true, 'call_to_action_enable' );

        if ( true !== $enable_call_to_action ) {
            return false;
        }

        // Get call_to_action section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_call_to_action_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render call_to_action section now.
        corporate_education_pro_render_call_to_action_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_primary_content_action', 'corporate_education_pro_add_call_to_action_section', 50 );


if ( ! function_exists( 'corporate_education_pro_get_call_to_action_section_details' ) ) :
    /**
    * call_to_action section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input call_to_action section details.
    */
    function corporate_education_pro_get_call_to_action_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // call_to_action type
        $call_to_action_content_type  = $options['call_to_action_type'];

        $content = array();
        switch ( $call_to_action_content_type ) {
            case 'demo':
                $content[0]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/promotion.jpg';
                $content[0]['title']    = esc_html__( 'Your success..!! Is our goal..!!', 'corporate-education-pro' );
                $content[0]['excerpt']  = esc_html__( 'Build your career with us', 'corporate-education-pro' );
                $content[0]['call_to_action_btn_label_1']  = esc_html__( 'Start Learning', 'corporate-education-pro' );
                $content[0]['call_to_action_btn_label_2']  = esc_html__( 'Contact Us Now', 'corporate-education-pro' );
                $content[0]['call_to_action_btn_url_1']    = '#';
                $content[0]['call_to_action_btn_url_2']    = '#';
            break;        
 
            case 'custom':
                $options = corporate_education_pro_get_theme_options();
                $content[0]['img_array'][0] = ! empty( $options['call_to_action_image'] ) ? $options['call_to_action_image'] : get_template_directory_uri() . '/assets/uploads/promotion.jpg';
                $content[0]['title']    = ! empty( $options['call_to_action_title'] ) ? $options['call_to_action_title'] : '';
                $content[0]['excerpt']  = ! empty( $options['call_to_action_sub_title'] ) ? $options['call_to_action_sub_title'] : '';
                $content[0]['call_to_action_btn_label_1']  = ! empty( $options['call_to_action_btn_label_1'] ) ? $options['call_to_action_btn_label_1'] : '';
                $content[0]['call_to_action_btn_label_2']  =  ! empty( $options['call_to_action_btn_label_2'] ) ? $options['call_to_action_btn_label_2'] : '';
                $content[0]['call_to_action_btn_url_1']    = ! empty( $options['call_to_action_btn_url_1'] ) ? $options['call_to_action_btn_url_1'] : '';
                $content[0]['call_to_action_btn_url_2']    = ! empty( $options['call_to_action_btn_url_2'] ) ? $options['call_to_action_btn_url_2'] : '';
                                            
            break;

            case 'post':
                $post_id = '';
                
                if ( ! empty( $options['call_to_action_content_post'] ) )
                    $post_id = absint( $options['call_to_action_content_post'] );

                // Bail if no valid pages are selected.
                if ( empty( $post_id ) ) {
                    return $input;
                }

                $img_array = null;
                if ( has_post_thumbnail( $post_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'full' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-1920x1080.jpg';
                }
                if ( isset( $img_array ) ) {
                    $content[0]['img_array'] = $img_array;
                }
                $content[0]['title']    = get_the_title( $post_id );
                $content[0]['url']      = get_the_permalink( $post_id );
                $content[0]['excerpt']  = corporate_education_pro_trim_content( 7, get_post( $post_id ) );
                                            
            break;

            case 'page':
                $page_id = '';
                
                if ( ! empty( $options['call_to_action_content_page'] ) )
                    $page_id = absint( $options['call_to_action_content_page'] );

                // Bail if no valid pages are selected.
                if ( empty( $page_id ) ) {
                    return $input;
                }

                $img_array = null;
                if ( has_post_thumbnail( $page_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'full' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-1920x1080.jpg';
                }
                if ( isset( $img_array ) ) {
                    $content[0]['img_array'] = $img_array;
                }
                $content[0]['title']    = get_the_title( $page_id );
                $content[0]['url']      = get_the_permalink( $page_id );
                $content[0]['excerpt']  = corporate_education_pro_trim_content( 7, get_post( $page_id ) );
                                            
            break;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// call_to_action section content details.
add_filter( 'corporate_education_pro_filter_call_to_action_section_details', 'corporate_education_pro_get_call_to_action_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_call_to_action_section' ) ) :
    /**
    * Start call_to_action section
    *
    * @return string call_to_action content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_call_to_action_section( $content_details ) {
        $options = corporate_education_pro_get_theme_options();
        $call_to_action_content_type  = $options['call_to_action_type'];
        $read_more = ! empty( $options['read_more_text'] ) ? $options['read_more_text'] : esc_html__( 'Learn More', 'corporate-education-pro' );

        if ( empty( $content_details ) ) {
            return;
        }

        foreach ( $content_details as $content_detail ) :
        ?>
            <section id="promotion" class="page-section align-center parallax" style="background-image:url('<?php echo esc_url( $content_detail['img_array'][0] ); ?>')" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
                <div class="black-overlay"></div>
                <div class="wrapper">

                    <header class="entry-header">
                        <?php if ( ! empty( $content_detail['title'] ) ) : ?>
                            <h2 class="entry-title"><?php echo esc_html( $content_detail['title'] ); ?></h2>
                        <?php endif; 
                        if ( ! empty( $content_detail['excerpt'] ) ) : ?>
                            <p class="entry-title-desc"><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                        <?php endif; ?>
                    </header>

                    <?php if ( in_array( $call_to_action_content_type, array( 'custom', 'demo' ) ) ) :
                        if ( ! empty( $content_detail['call_to_action_btn_url_1'] ) || ! empty( $content_detail['call_to_action_btn_url_2'] ) ) : ?>

                            <div class="view-more">
                                <?php if ( ! empty( $content_detail['call_to_action_btn_url_1'] ) ) : ?>
                                    
                                    <a href="<?php echo esc_url( $content_detail['call_to_action_btn_url_1'] ); ?>" class="btn btn-orange"><?php echo esc_html( $content_detail['call_to_action_btn_label_1'] ); ?></a>
                                
                                <?php endif; 
                                if ( ! empty( $content_detail['call_to_action_btn_url_2'] ) ) : ?>
                                    
                                    <a href="<?php echo esc_url( $content_detail['call_to_action_btn_url_2'] ); ?>" class="btn btn-white-transparent"><?php echo esc_html( $content_detail['call_to_action_btn_label_2'] ); ?></a>
                                
                                <?php endif; ?>
                            </div><!-- .view-more -->

                        <?php endif; 
                        
                    elseif ( in_array( $call_to_action_content_type, array( 'post', 'page' ) ) ) : ?>
                        
                        <div class="view-more">
                            <a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="btn btn-white-transparent"><?php echo esc_html( $read_more ); ?></a>
                        </div><!-- .view-more -->
                    
                    <?php endif; ?>
                </div><!-- .wrapper -->
            </section><!-- #promotion -->
        <?php endforeach;
    }
endif;