<?php 
/**
 * Courses section
 *
 * This is the template for the content of courses section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_courses_section' ) ) :
    /**
    * Add courses section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_courses_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if courses is enabled
        $enable_courses = apply_filters( 'corporate_education_pro_section_status', true, 'courses_enable' );

        if ( true !== $enable_courses ) {
            return false;
        }

        // Get courses section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_courses_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render courses section now.
        corporate_education_pro_render_courses_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_primary_content_action', 'corporate_education_pro_add_courses_section', 40 );


if ( ! function_exists( 'corporate_education_pro_get_courses_section_details' ) ) :
    /**
    * courses section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input courses section details.
    */
    function corporate_education_pro_get_courses_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // courses type
        $courses_content_type  = $options['courses_content_type'];
        $no_of_courses = ! empty( $options['no_of_courses'] ) ? $options['no_of_courses'] : 3;

        $content = array();
        switch ( $courses_content_type ) {
          	case 'demo':
                $title = array (
                    1 => esc_html__( 'Painting & Sketch', 'corporate-education-pro' ),
                    2 => esc_html__( 'Study Biology', 'corporate-education-pro' ),
                    3 => esc_html__( 'Basic Photography', 'corporate-education-pro' ),
                    );
                for ( $i = 1; $i <= 3; $i++ ) :
                    $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/course-0' . $i . '.jpg';
                    $content[$i]['img_array'][1] = 400;
                    $content[$i]['img_array'][2] = 270;
                    $content[$i]['title']    = $title[$i];
                    $content[$i]['url']      = '#';
                    $content[$i]['excerpt']  = esc_html__( 'Interdum et malesuada fames ac ante ipsum primis in faucibus. Fusce male sua da ante sed rhoncus blandit...', 'corporate-education-pro' );
                endfor;
            break;        

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['courses_content_post'] ) )
                    $ids = ( array ) $options['courses_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );  
                
          	break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['courses_content_category'] ) ) {
                    $cat_id = $options['courses_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => absint( $no_of_courses ),
                );
            break;

            case 'course':
                $ids = array();
                
                if ( ! empty( $options['courses_content_course'] ) )
                    $ids = ( array ) $options['courses_content_course'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'tp-course',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );  

            break;

            case 'course-category':
                $cat_id = '';
                if ( ! empty( $options['courses_content_course_category'] ) ) {
                    $cat_id = $options['courses_content_course_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'post_type'         => 'tp-course',
                    'posts_per_page'    => absint( $no_of_courses ),
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'tp-course-category',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    )
                );
                
            break;

            
        }

        if ( 'demo' != $courses_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $img_array = null;
                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'post-thumbnail' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-400x270.jpg';
                        $img_array[1] =  400;
                        $img_array[2] =  270;
                    }
                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                    }

                    $content[$i]['id']       = $post_id;
                    $content[$i]['title']    = get_the_title( $post_id );
                    $content[$i]['url']      = get_the_permalink( $post_id );
                    $content[$i]['excerpt']  = corporate_education_pro_trim_content( 15, $post );
                    $i++;
                endforeach;
            endif;
            wp_reset_postdata();
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// courses section content details.
add_filter( 'corporate_education_pro_filter_courses_section_details', 'corporate_education_pro_get_courses_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_courses_section' ) ) :
    /**
    * Start courses section
    *
    * @return string courses content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_courses_section( $content_details ) {
        $options = corporate_education_pro_get_theme_options();
        $title = ! empty( $options['courses_title'] ) ? $options['courses_title'] : '';
        $sub_title = ! empty( $options['courses_sub_title'] ) ? $options['courses_sub_title'] : '';
        $courses_content_type  = $options['courses_content_type'];

        $category_link  = '';
        $cat_name       = '';
        if ( $courses_content_type == 'category' ) {
            $category_link  = get_category_link( $options['courses_content_category'] );
            $cat_name       = get_the_category_by_ID( $options['courses_content_category'] );
        } elseif ( $courses_content_type == 'course-category' ) {
            $category_link  = get_term_link( $options['courses_content_course_category' ], 'tp-course-category' );
            $term           = get_term_by('id', $options['courses_content_course_category' ] , 'tp-course-category' );
            $cat_name       = $term->name;
        } elseif ( $courses_content_type == 'demo' ) {
            $category_link  = '#';
            $cat_name       = esc_html__( 'Courses', 'corporate-education-pro' );
        }

        if ( empty( $content_details ) ) {
            return;
        }
        ?>
            <section id="featured-courses" class="page-section">
                <div class="white-shape top move-up left"></div>
                <div class="white-shape bottom move-down right"></div>
                <div class="white-shape bottom full-width"></div>

                <div class="wrapper">
                    <header class="entry-header align-center">
                        <?php if ( ! empty( $title ) ) : ?>
                            <h2 class="entry-title"><?php echo esc_html( $title ); ?></h2>
                        <?php endif; 
                        if ( ! empty( $sub_title ) ) : ?>
                            <p class="entry-title-desc"><?php echo esc_html( $sub_title ); ?></p>
                        <?php endif; ?>
                    </header>

                    <div class="entry-content col-3">
                        <?php foreach( $content_details as $content_detail ) : ?>
                            <div class="hentry">
                                <div class="featured-course-wrapper">
                                    <figure class="featured-image">
                                        <div class="white-shape top"></div>
                                        <div class="white-shape top right"></div>
                                        <div class="white-shape bottom"></div>
                                        <div class="white-shape bottom left"></div>

                                        <a href="<?php echo esc_url( $content_detail['url'] ); ?>"><img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" width="<?php echo esc_attr( $content_detail['img_array'][1] ); ?>" height="<?php echo esc_attr( $content_detail['img_array'][2] ); ?>" alt="<?php echo esc_attr( $content_detail['title'] ); ?>"></a>
                                        <?php if ( in_array( $courses_content_type , array( 'course', 'course-category' ) ) && has_action( 'tp_course_price_action' ) ) : 
                                            do_action( 'tp_course_price_action', absint( $content_detail['id'] ) );
                                        elseif ( 'demo' == $courses_content_type ) : ?>
                                            <span class="tp-course-price"><?php esc_html_e( '$545', 'corporate-education-pro' ); ?></span>
                                        <?php endif; ?>
                                    </figure>
                                    <div class="entry-container">
                                        <h5 class="featured-title"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                                        <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                    </div><!-- .entry-container -->
                                </div><!-- .featured-course-wrapper -->
                            </div><!-- .hentry -->
                        <?php endforeach; ?>
                    </div><!-- .entry-content -->
                    <?php if ( ! empty( $category_link ) ) : ?>
                        <div class="view-more align-center">
                            <a href="<?php echo esc_url( $category_link ); ?>" class="btn btn-blue-transparent"><?php printf( '%s ' . esc_html( $cat_name ), esc_html__( 'View all', 'corporate-education-pro' ) ); ?></a>
                        </div>
                    <?php endif; ?>
                </div><!-- .wrapper -->
            </section><!-- #featured-courses -->
        <?php }
endif;
