<?php
/**
 * corporate_education_pro options
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

if ( ! function_exists( 'corporate_education_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function corporate_education_pro_typography_options(){
        $choices = array(
          'default'         => esc_html__( 'Default', 'corporate-education-pro' ),
          'header-font-1'   => esc_html__( 'Rajdhani', 'corporate-education-pro' ),
          'header-font-2'   => esc_html__( 'Cherry Swash', 'corporate-education-pro' ),
          'header-font-3'   => esc_html__( 'Philosopher', 'corporate-education-pro' ),
          'header-font-4'   => esc_html__( 'Slabo 27px', 'corporate-education-pro' ),
          'header-font-5'   => esc_html__( 'Dosis', 'corporate-education-pro' ),
        );

        $output = apply_filters( 'corporate_education_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
          ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'corporate_education_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function corporate_education_pro_body_typography_options(){
        $choices = array(
          'default'         => esc_html__( 'Default', 'corporate-education-pro' ),
          'body-font-1'     => esc_html__( 'News Cycle', 'corporate-education-pro' ),
          'body-font-2'     => esc_html__( 'Pontano Sans', 'corporate-education-pro' ),
          'body-font-3'     => esc_html__( 'Gudea', 'corporate-education-pro' ),
          'body-font-4'     => esc_html__( 'Quattrocento', 'corporate-education-pro' ),
          'body-font-5'     => esc_html__( 'Khand', 'corporate-education-pro' ),
        );

        $output = apply_filters( 'corporate_education_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
          ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'corporate_education_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function corporate_education_pro_site_layout() {
        $corporate_education_pro_site_layout = array(
            'wide'  => esc_html__( 'Wide', 'corporate-education-pro' ),
            'boxed' => esc_html__( 'Boxed', 'corporate-education-pro' ),
        );

        $output = apply_filters( 'corporate_education_pro_site_layout', $corporate_education_pro_site_layout );

        return $output;
    }
endif;


if ( ! function_exists( 'corporate_education_pro_theme_color' ) ) :
    /**
     * theme color
     * @return array site layout options
     */
    function corporate_education_pro_theme_color() {
        $corporate_education_pro_theme_color = array(
            'blue'      => esc_html__( 'Blue', 'corporate-education-pro' ),
            'red'       => esc_html__( 'Red', 'corporate-education-pro' ),
            'green'     => esc_html__( 'Green', 'corporate-education-pro' ),
            'black'     => esc_html__( 'Black', 'corporate-education-pro' ),
            'purple'    => esc_html__( 'Purple', 'corporate-education-pro' ),
            'yellow'    => esc_html__( 'Yellow', 'corporate-education-pro' ),
        );

        $output = apply_filters( 'corporate_education_pro_theme_color', $corporate_education_pro_theme_color );

        return $output;
    }
endif;


if ( ! function_exists( 'corporate_education_pro_theme_layout' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function corporate_education_pro_theme_layout() {
        $corporate_education_pro_theme_layout = array(
            'curve'         => esc_html__( 'Curve Edges', 'corporate-education-pro' ),
            'remove-curves' => esc_html__( 'Straight Edges', 'corporate-education-pro' ),
        );

        $output = apply_filters( 'corporate_education_pro_theme_layout', $corporate_education_pro_theme_layout );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_theme_menu' ) ) :
    /**
     * menu style
     * @return array menu style
     */
    function corporate_education_pro_theme_menu() {
        $corporate_education_pro_theme_menu = array(
            'modern-menu'   => esc_html__( 'Modern Menu', 'corporate-education-pro' ),
            'classic-menu'  => esc_html__( 'Classic Menu', 'corporate-education-pro' ),
        );

        $output = apply_filters( 'corporate_education_pro_theme_menu', $corporate_education_pro_theme_menu );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function corporate_education_pro_sidebar_position() {
        $corporate_education_pro_sidebar_position = array(
            'right-sidebar' => esc_html__( 'Right', 'corporate-education-pro' ),
            'left-sidebar'  => esc_html__( 'Left', 'corporate-education-pro' ),
            'no-sidebar'    => esc_html__( 'No Sidebar', 'corporate-education-pro' ),
        );

        $output = apply_filters( 'corporate_education_pro_sidebar_position', $corporate_education_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'corporate_education_pro_selected_sidebar' ) ) :
    /**
     * Sidebar selected
     * @return array Sidbar selected
     */
    function corporate_education_pro_selected_sidebar() {
        $corporate_education_pro_selected_sidebar = array(
            'sidebar-1'                                   => esc_html__( 'Primary Sidebar', 'corporate-education-pro' ),
            'corporate-education-pro-optional-sidebar'    => esc_html__( 'Optional Sidebar 1', 'corporate-education-pro' ),
            'corporate-education-pro-optional-sidebar-2'  => esc_html__( 'Optional Sidebar 2', 'corporate-education-pro' ),
            'corporate-education-pro-optional-sidebar-3'  => esc_html__( 'Optional Sidebar 3', 'corporate-education-pro' ),
        );

        $output = apply_filters( 'corporate_education_pro_selected_sidebar', $corporate_education_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'corporate_education_pro_header_image' ) ) :
    /**
     * Header image options
     * @return array Header image options
     */
    function corporate_education_pro_header_image() {
        $corporate_education_pro_header_image = array(
            'show-both' => esc_html__( 'Show Both( Featured and Header Image )', 'corporate-education-pro' ),
            'enable'    => esc_html__( 'Enable( Featured Image )', 'corporate-education-pro' ),
            'default'   => esc_html__( 'Default ( Customizer Header Image )', 'corporate-education-pro' ),
        );

        $output = apply_filters( 'corporate_education_pro_header_image', $corporate_education_pro_header_image );

        return $output;
    }
endif;


if ( ! function_exists( 'corporate_education_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function corporate_education_pro_pagination_options() {
        $corporate_education_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'corporate-education-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'corporate-education-pro' ),
            'infinite'  => esc_html__( 'Infinite Scroll', 'corporate-education-pro' ),
        );

        $output = apply_filters( 'corporate_education_pro_pagination_options', $corporate_education_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_headline_options' ) ) :
    /**
     * Headline
     * @return array site headline options
     */
    function corporate_education_pro_headline_options() {
        $corporate_education_pro_headline_options = array(
            'demo'      => esc_html__( 'Demo', 'corporate-education-pro' ),
            'post'      => esc_html__( 'Post', 'corporate-education-pro' ),
            'category'  => esc_html__( 'Category', 'corporate-education-pro' ),
        );

        $output = apply_filters( 'corporate_education_pro_headline_options', $corporate_education_pro_headline_options );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_slider_effect' ) ) :
    /**
     * Slider effects
     * @return array Slider effects
     */
    function corporate_education_pro_slider_effect() {
      $corporate_education_pro_slider_effect = array(
            'fade'                                        => esc_html__( 'Fade', 'corporate-education-pro' ),
            'cubic-bezier(0.250, 0.250, 0.750, 0.750)'    => esc_html__( 'Linear', 'corporate-education-pro' ),
            'cubic-bezier(0.250, 0.100, 0.250, 1.000)'    => esc_html__( 'Ease', 'corporate-education-pro' ),
            'cubic-bezier(0.950, 0.050, 0.795, 0.035)'    => esc_html__( 'cubic', 'corporate-education-pro' ),
            'cubic-bezier(0.600, -0.280, 0.735, 0.045)'   => esc_html__( 'Ease In Back', 'corporate-education-pro' ),
            'cubic-bezier(0.785, 0.135, 0.150, 0.860)'    => esc_html__( 'EaseInOutCirc', 'corporate-education-pro' ),
            'cubic-bezier(0.680, -0.550, 0.265, 1.550)'   => esc_html__( 'EaseInOutBack', 'corporate-education-pro' ),
        );

        $output =  apply_filters( 'corporate_education_pro_slider_effect', $corporate_education_pro_slider_effect );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_slider_transition_duration' ) ) :
    /**
     * Slider transition duration
     * @return array Slider transition duration
     */
    function corporate_education_pro_slider_transition_duration() {
        $corporate_education_pro_slider_transition_duration = array(
            '1000'    => esc_html__( '1 sec', 'corporate-education-pro' ),
            '2000'    => esc_html__( '2 sec', 'corporate-education-pro' ),
            '3000'    => esc_html__( '3 sec', 'corporate-education-pro' ),
            '4000'    => esc_html__( '4 sec', 'corporate-education-pro' ),
            '5000'    => esc_html__( '5 sec', 'corporate-education-pro' ),
        );

        $output =  apply_filters( 'corporate_education_pro_slider_transition_duration', $corporate_education_pro_slider_transition_duration );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_common_content_type' ) ) :
    /**
     * Common content types
     * @return array Content types
     */
    function corporate_education_pro_common_content_type() {
        $corporate_education_pro_content_type = array(
            'demo'      => esc_html__( 'Demo', 'corporate-education-pro' ),
            'page'      => esc_html__( 'Page', 'corporate-education-pro' ),
            'post'      => esc_html__( 'Post', 'corporate-education-pro' ),
            'category'  => esc_html__( 'Category', 'corporate-education-pro' ),
        ); 

        $output = apply_filters( 'corporate_education_pro_common_content_type', $corporate_education_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_intro_content_type' ) ) :
    /**
     * Common content types
     * @return array Content types
     */
    function corporate_education_pro_intro_content_type() {
        $corporate_education_pro_content_type = array(
            'demo'      => esc_html__( 'Demo', 'corporate-education-pro' ),
            'custom'    => esc_html__( 'Custom', 'corporate-education-pro' ),
            'page'      => esc_html__( 'Page', 'corporate-education-pro' ),
            'post'      => esc_html__( 'Post', 'corporate-education-pro' ),
        ); 

        $output = apply_filters( 'corporate_education_pro_intro_content_type', $corporate_education_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_about_content_type' ) ) :
    /**
     * Common content types
     * @return array Content types
     */
    function corporate_education_pro_about_content_type() {
        $corporate_education_pro_content_type = array(
            'demo'      => esc_html__( 'Demo', 'corporate-education-pro' ),
            'page'      => esc_html__( 'Page', 'corporate-education-pro' ),
            'post'      => esc_html__( 'Post', 'corporate-education-pro' ),
            'custom'    => esc_html__( 'Custom', 'corporate-education-pro' ),
        ); 

        $output = apply_filters( 'corporate_education_pro_about_content_type', $corporate_education_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_about_content_column' ) ) :
    /**
     * Common content types
     * @return array Content types
     */
    function corporate_education_pro_about_content_column() {
        $corporate_education_pro_content_type = array(
            '1'      => esc_html__( 'One Column', 'corporate-education-pro' ),
            '2'      => esc_html__( 'Two Column', 'corporate-education-pro' ),
            '3'      => esc_html__( 'Three Column', 'corporate-education-pro' ),
        ); 

        $output = apply_filters( 'corporate_education_pro_about_content_column', $corporate_education_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_courses_content_type' ) ) :
    /**
     * courses content types
     * @return array Content types
     */
    function corporate_education_pro_courses_content_type() {
        $corporate_education_pro_content_type = array(
            'demo'      => esc_html__( 'Demo', 'corporate-education-pro' ),
            'post'      => esc_html__( 'Post', 'corporate-education-pro' ),
            'category'  => esc_html__( 'Category', 'corporate-education-pro' ),
        ); 
        if ( class_exists( 'TP_Education' ) ) {
            $custom_choice = array();
            if( post_type_exists('tp-course')){
                $custom_choice['course'] = esc_html__( 'Course', 'corporate-education-pro' );
                $custom_choice['course-category'] = esc_html__( 'Courses Category', 'corporate-education-pro' );

            }
            $corporate_education_pro_content_type = array_merge( $corporate_education_pro_content_type, $custom_choice );
        }

        $output = apply_filters( 'corporate_education_pro_courses_content_type', $corporate_education_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_latest_news_content_type' ) ) :
    /**
     * latest news content types
     * @return array Content types
     */
    function corporate_education_pro_latest_news_content_type() {
        $corporate_education_pro_content_type = array(
            'demo'          => esc_html__( 'Demo', 'corporate-education-pro' ),
            'recent-post'   => esc_html__( 'Recent Posts', 'corporate-education-pro' ),
            'category'      => esc_html__( 'Category', 'corporate-education-pro' ),
        ); 
        if ( class_exists( 'TP_Education' ) ) {
            $custom_choice = array();
            if( post_type_exists('tp-event')){
                $custom_choice['recent-event'] = esc_html__( 'Recent Events', 'corporate-education-pro' );
                $custom_choice['event-category'] = esc_html__( 'Event Category', 'corporate-education-pro' );
            }
            $corporate_education_pro_content_type = array_merge( $corporate_education_pro_content_type, $custom_choice );
        }

        $output = apply_filters( 'corporate_education_pro_latest_news_content_type', $corporate_education_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_team_content_type' ) ) :
    /**
     * team content types
     * @return array Content types
     */
function corporate_education_pro_team_content_type() {
    $corporate_education_pro_content_type = array(
        'demo'      => esc_html__( 'Demo', 'corporate-education-pro' ),
        'post'      => esc_html__( 'Post', 'corporate-education-pro' ),
        'category'  => esc_html__( 'Category', 'corporate-education-pro' ),
        ); 
    if ( class_exists( 'TP_Education' ) ) {
        $custom_choice = array();
        if( post_type_exists('tp-team')){
            $custom_choice['team'] = esc_html__( 'Team', 'corporate-education-pro' );
            $custom_choice['team-category'] = esc_html__( 'Team Category', 'corporate-education-pro' );
        }
        $corporate_education_pro_content_type = array_merge( $corporate_education_pro_content_type, $custom_choice );
    }

    $output = apply_filters( 'corporate_education_pro_team_content_type', $corporate_education_pro_content_type );

    return $output;
}
endif;

if ( ! function_exists( 'corporate_education_pro_call_to_action' ) ) :
    /**
     * goal content types
     * @return array Content types
     */
    function corporate_education_pro_call_to_action() {
        $corporate_education_pro_content_type = array(
            'demo'      => esc_html__( 'Demo', 'corporate-education-pro' ),
            'custom'    => esc_html__( 'Custom', 'corporate-education-pro' ),
            'post'      => esc_html__( 'Post', 'corporate-education-pro' ),
            'page'      => esc_html__( 'Page', 'corporate-education-pro' ),
        ); 

        $output = apply_filters( 'corporate_education_pro_call_to_action', $corporate_education_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_testimonial_content_type' ) ) :
    /**
     * testimonial content types
     * @return array Content types
     */
    function corporate_education_pro_testimonial_content_type() {
        $corporate_education_pro_content_type = array(
            'demo'      => esc_html__( 'Demo', 'corporate-education-pro' ),
            'post'      => esc_html__( 'Post', 'corporate-education-pro' ),
            'category'  => esc_html__( 'Category', 'corporate-education-pro' ),
            ); 
        if ( class_exists( 'TP_Education' ) ) {
            $custom_choice = array();
            if( post_type_exists('tp-testimonial')){
                $custom_choice['testimonial'] = esc_html__( 'Testimonial', 'corporate-education-pro' );
                $custom_choice['recent-testimonial'] = esc_html__( 'Recent Testimonial', 'corporate-education-pro' );
            }
            $corporate_education_pro_content_type = array_merge( $corporate_education_pro_content_type, $custom_choice);
        }

        $output = apply_filters( 'corporate_education_pro_testimonial_content_type', $corporate_education_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_gallery_content_type' ) ) :
    /**
     * Common content types
     * @return array Content types
     */
    function corporate_education_pro_gallery_content_type() {
        $corporate_education_pro_content_type = array(
            'demo'      => esc_html__( 'Demo', 'corporate-education-pro' ),
            'post'      => esc_html__( 'Post', 'corporate-education-pro' ),
            'category'  => esc_html__( 'Category', 'corporate-education-pro' ),
        ); 

        $output = apply_filters( 'corporate_education_pro_gallery_content_type', $corporate_education_pro_content_type );

        return $output;
    }
endif;

/* CUSTOM TEMPLATE */

if ( ! function_exists( 'corporate_education_pro_study_abroad_destination' ) ) :
    /**
     * Common content types
     * @return array Content types
     */
    function corporate_education_pro_study_abroad_destination() {
        $corporate_education_pro_content_type = array(
            'post'      => esc_html__( 'Post', 'corporate-education-pro' ),
            'category'  => esc_html__( 'Category', 'corporate-education-pro' ),
        ); 
        if ( class_exists( 'TP_Education' ) ) {
            $custom_choice = array();
            if( post_type_exists('tp-excursion') ){
                $custom_choice['excursion'] = esc_html__( 'Excursion', 'corporate-education-pro' );
                $custom_choice['excursion-category'] = esc_html__( 'Excursion Category', 'corporate-education-pro' );
            }
            $corporate_education_pro_content_type = array_merge( $corporate_education_pro_content_type, $custom_choice   );
        }

        $output = apply_filters( 'corporate_education_pro_study_abroad_destination', $corporate_education_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_study_guide' ) ) :
    /**
     * Common content types
     * @return array Content types
     */
    function corporate_education_pro_study_guide() {
        $corporate_education_pro_content_type = array(
            'post'      => esc_html__( 'Post', 'corporate-education-pro' ),
            'category'  => esc_html__( 'Category', 'corporate-education-pro' ),
        ); 

        $output = apply_filters( 'corporate_education_pro_study_guide', $corporate_education_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_goal' ) ) :
    /**
     * goal content types
     * @return array Content types
     */
    function corporate_education_pro_goal() {
        $corporate_education_pro_content_type = array(
            'post'      => esc_html__( 'Post', 'corporate-education-pro' ),
            'page'      => esc_html__( 'Page', 'corporate-education-pro' ),
        ); 

        $output = apply_filters( 'corporate_education_pro_goal', $corporate_education_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_message' ) ) :
    /**
     * message content types
     * @return array Content types
     */
    function corporate_education_pro_message() {
        $corporate_education_pro_content_type = array(
            'post'      => esc_html__( 'Post', 'corporate-education-pro' ),
            'page'      => esc_html__( 'Page', 'corporate-education-pro' ),
            'custom'    => esc_html__( 'Custom', 'corporate-education-pro' ),
        ); 

        $output = apply_filters( 'corporate_education_pro_message', $corporate_education_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_about_team_content_type' ) ) :
    /**
     * about team content types
     * @return array Content types
     */
    function corporate_education_pro_about_team_content_type() {
        $corporate_education_pro_content_type = array(
            'post'      => esc_html__( 'Post', 'corporate-education-pro' ),
            'category'  => esc_html__( 'Category', 'corporate-education-pro' ),
        ); 
        if ( class_exists( 'TP_Education' ) ) {
            $custom_choice = array();
            if( post_type_exists('tp-team')){
                $custom_choice['team'] = esc_html__( 'Team', 'corporate-education-pro' );
                $custom_choice['team-category'] = esc_html__( 'Team Category', 'corporate-education-pro' );
            }
            $corporate_education_pro_content_type = array_merge( $corporate_education_pro_content_type, $custom_choice);
        }

        $output = apply_filters( 'corporate_education_pro_team_content_type', $corporate_education_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'corporate_education_pro_map' ) ) :
    /**
     * map content types
     * @return array Content types
     */
    function corporate_education_pro_map() {
        $corporate_education_pro_content_type = array(
            'shortcode' => esc_html__( 'Shortcode', 'corporate-education-pro' ),
            'embed'     => esc_html__( 'Embed Code', 'corporate-education-pro' ),
        ); 

        $output = apply_filters( 'corporate_education_pro_map', $corporate_education_pro_content_type );

        return $output;
    }
endif;